"use client";

import Link from "next/link";
import { usePathname, useSearchParams } from "next/navigation";
import { useEffect } from "react";

export const SmoothLink = ({
	href,
	children,
	className,
}: {
	href: string;
	className?: string;
	children: React.ReactNode;
}) => {
	const pathname = usePathname();
	const searchParams = useSearchParams();

	useEffect(() => {
		// Add small delay to ensure DOM is ready
		const timeoutId = setTimeout(() => {
			const hash = window.location.hash;
			if (hash) {
				const targetElement = document.querySelector(hash);
				if (targetElement) {
					targetElement.scrollIntoView({
						behavior: "smooth",
						block: "start",
					});
				}
			}
		}, 100);

		// Cleanup timeout to prevent memory leaks
		return () => clearTimeout(timeoutId);
	}, [pathname, searchParams]);

	return (
		<Link href={href as any} className={className}>
			{children}
		</Link>
	);
};
